@@ -1,7 +1,7 @@
 # vim:ts=4:sw=4:sts=4:et
 # -*- coding: utf-8 -*-
 """
-Layout-related code in the IGraph library.
+Layout-related code in the igraph library.
 
 This package contains the implementation of the L{Layout} object.
 """
@@ -189,7 +189,7 @@ class Layout:
             raise ValueError("scaling factor must be given")
         elif len(scaling) == 1:
             if type(scaling[0]) == int or type(scaling[0]) == float:
-                scaling = scaling * self._dim
+                scaling *= self._dim
             else:
                 scaling = scaling[0]
         if len(scaling) != self._dim:
